==> cook.1.7.tar.gz: cook.1.7/test/00/t0048a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 1994 Peter Miller.
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
# MANIFEST: Test the include-cooked functionality
#
work=/tmp/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 1; fi

if test "$1" != "" ; then bin="$here/$1/bin"; else bin="$here/bin"; fi

fail()
{
	set +x
	echo 'FAILED test of the include-cooked functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
trap \"fail\" 1 2 3 15

mkdir $work
if test $? -ne 0 ; then exit 1; fi
cd $work
if test $? -ne 0 ; then fail; fi

PATH=${bin}:${PATH}
export PATH

#
# use clever C include dependencies
#
cat > Howto.cook << 'fubar'

obj = [fromto %.c %.o [glob *.c]];

test.out: test
{
	./test > test.out;
}

%.o: %.c
{
	cc -c %.c;
}

%.d: %.c
{
	c_incl -nc -ns -eia %.c -prefix "'%.o %.d: %.c'" -suffix "';'" > %.d;
}

#include-cooked [fromto %.o %.d [obj]]

test: [obj]
{
	cc -o test [obj];
}
fubar
if test $? -ne 0 ; then fail; fi

cat > test.c << 'fubar'
test()
{
	printf("Hello, World!\n");
}
fubar
if test $? -ne 0 ; then fail; fi

cat > test.h << 'fubar'
void test();
fubar
if test $? -ne 0 ; then fail; fi

cat > main.c << 'fubar'
#include "test.h"
main()
{
	test();
	exit(0);
}
fubar
if test $? -ne 0 ; then fail; fi

cook -nl > /dev/null 2>&1
if test $? -ne 0 ; then fail; fi

cat > test.ok << 'fubar'
Hello, World!
fubar
if test $? -ne 0 ; then fail; fi

diff test.ok test.out
if test $? -ne 0 ; then fail; fi

cat > test.ok << 'fubar'
main.o main.d: main.c
test.h
;
fubar
if test $? -ne 0 ; then fail; fi

diff test.ok main.d
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

==> cook_2.25.orig.tar.gz: cook-2.25/test/00/t0048a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 1994, 1997, 1998 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the include-cooked functionality
#
work=${COOK_TMP:-/tmp}/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 1; fi

SHELL=/bin/sh
export SHELL

bin="$here/${1-.}/bin"

fail()
{
	set +x
	echo 'FAILED test of the include-cooked functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
trap \"fail\" 1 2 3 15

mkdir $work $work/lib
if test $? -ne 0 ; then exit 1; fi
cd $work
if test $? -ne 0 ; then fail; fi

#
# Use the default error messages.  There is no other way to get
# predictable test behaviour on the unknown systems we will be tested on.
#
COOK_MESSAGE_LIBRARY=$work/no-such-dir
export COOK_MESSAGE_LIBRARY
unset LANG

PATH=${bin}:${PATH}
export PATH

#
# use clever C include dependencies
#
cat > Howto.cook << 'fubar'
cc = [getenv CC]; if [not [cc]] then
{ cc = [find_command gcc]; if [not [cc]] then cc = cc; }

obj = [fromto %.c %.o [glob *.c]];

test.out: test
{
	./test > test.out;
}

%.o: %.c
{
	[cc] -c %.c;
}

%.d: %.c
{
	c_incl -nc -ns -eia %.c -prefix "'%.o %.d: %.c'" -suffix "';'" > %.d;
}

#include-cooked [fromto %.o %.d [obj]]

test: [obj]
{
	[cc] -o test [obj];
}
fubar
if test $? -ne 0 ; then fail; fi

cat > test.c << 'fubar'
test()
{
	printf("Hello, World!\n");
}
fubar
if test $? -ne 0 ; then fail; fi

cat > test.h << 'fubar'
void test();
fubar
if test $? -ne 0 ; then fail; fi

cat > main.c << 'fubar'
#include "test.h"
main()
{
	test();
	exit(0);
}
fubar
if test $? -ne 0 ; then fail; fi

cook -nl > /dev/null 2>&1
if test $? -ne 0 ; then fail; fi

cat > test.ok << 'fubar'
Hello, World!
fubar
if test $? -ne 0 ; then fail; fi

diff test.ok test.out
if test $? -ne 0 ; then fail; fi

cat > test.ok << 'fubar'
main.o main.d: main.c
test.h
;
fubar
if test $? -ne 0 ; then fail; fi

diff test.ok main.d
if test $? -ne 0 ; then fail; fi

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass
